@@ -21,6 +21,7 @@
  */
 
 #include "config.h"
+#include <string.h>
 #include <errno.h>
 #include "gdk-pixbuf-transform.h"
 #include "io-gif-animation.h"
@@ -104,6 +105,7 @@ gdk_pixbuf_gif_anim_get_static_image (GdkPixbufAnimation *animation)
 {
         GdkPixbufGifAnim *gif_anim;
         GdkPixbufAnimationIter *iter;
+        GdkPixbuf *pixbuf;
         GTimeVal start_time = { 0, 0 };
 
         gif_anim = GDK_PIXBUF_GIF_ANIM (animation);
@@ -112,7 +114,10 @@ gdk_pixbuf_gif_anim_get_static_image (GdkPixbufAnimation *animation)
                 return NULL;
 
         iter = gdk_pixbuf_gif_anim_get_iter (animation, &start_time);
-        return gdk_pixbuf_gif_anim_iter_get_pixbuf (iter);
+        pixbuf = gdk_pixbuf_gif_anim_iter_get_pixbuf (iter);
+        g_object_unref (iter);
+
+        return pixbuf;
 }
 G_GNUC_END_IGNORE_DEPRECATIONS
 
@@ -411,11 +416,15 @@ gdk_pixbuf_gif_anim_iter_get_pixbuf (GdkPixbufAnimationIter *anim_iter)
 
         /* If no rendered frame, render the first frame */
         if (anim->last_frame == NULL) {
+                gsize len = 0;
                 if (anim->last_frame_data == NULL)
                         anim->last_frame_data = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, anim->width, anim->height);
                 if (anim->last_frame_data == NULL)
                         return NULL;
-                memset (gdk_pixbuf_get_pixels (anim->last_frame_data), 0, gdk_pixbuf_get_rowstride (anim->last_frame_data) * anim->height);
+                if (g_size_checked_mul (&len, gdk_pixbuf_get_rowstride (anim->last_frame_data), anim->height))
+                        memset (gdk_pixbuf_get_pixels (anim->last_frame_data), 0, len);
+                else
+                        return NULL;
                 composite_frame (anim, g_list_nth_data (anim->frames, 0));
         }
 
